@@ -9,6 +9,9 @@ class Entity(models.Model):
         null=True,
         verbose_name=_('Client Session'),
     )
+    entity_id = models.BigIntegerField(
+        verbose_name=_('Entity ID'),
+    )
     hash_value = models.BigIntegerField(
         blank=False,
         null=False,
@@ -27,7 +30,7 @@ class Entity(models.Model):
         verbose_name=_('Phone'),
     )
     name = models.CharField(
-        max_length=50,
+        max_length=150,
         blank=True,
         null=True,
         verbose_name=_('Name'),
@@ -40,3 +43,6 @@ class Entity(models.Model):
     class Meta:
         verbose_name = _('Entity')
         verbose_name_plural = _('Entities')
+
+    def __str__(self):
+        return f'{self.entity_id} - {self.username} - {self.name}'
