@@ -11,14 +11,15 @@ from .sessions import LoginStatus
 class LoginQueryset(models.QuerySet):
     def expired(self):
         return self.filter(
-            Q(created_at__lt=now() - timedelta(minutes=5)) | Q(client_session__login_status__in=LoginStatus.approve())
+            Q(created_at__lt=now() - timedelta(minutes=5))
+            | Q(client_session__login_status__in=LoginStatus.approve())
         )
 
     def have_to_send_code(self):
         return self.filter(have_to_send_code=True).distinct('client_session')
 
     def have_to_login(self):
-        return self.filter(code__isnull=False).distinct('client_session')
+        return self.filter(Q(code__isnull=False) | Q(bot_token__isnull=False)).distinct('client_session')
 
 
 class LoginManager(models.Manager):
@@ -30,7 +31,9 @@ class LoginManager(models.Manager):
 
 
 class Login(models.Model):
-    client_session = models.ForeignKey('ClientSession', on_delete=models.CASCADE, verbose_name=_('Client session'))
+    client_session = models.ForeignKey(
+        'ClientSession', on_delete=models.CASCADE, verbose_name=_('Client session')
+    )
     have_to_send_code = models.BooleanField(default=True, verbose_name=_('Have to send code'))
     bot_token = models.CharField(
         max_length=255,
