@@ -2,12 +2,13 @@ import json
 
 from django.core.exceptions import ObjectDoesNotExist
 from django.http import JsonResponse
+from django.views.decorators.csrf import csrf_exempt
 
 from django_telethon.models import App, ClientSession, Login, LoginStatus
 
 
 def _get_data(request):
-    if 'application/json' in request.META.get('CONTENT_TYPE', ''):
+    if 'application/json' in request.headers.get('content-type', ''):
         data = request.body.decode('utf-8')
         data = json.loads(data)
     else:
@@ -15,6 +16,7 @@ def _get_data(request):
     return data
 
 
+@csrf_exempt
 def send_code_request_view(request):
     data = _get_data(request)
     phone_number = data.get('phone_number', None)
@@ -32,10 +34,13 @@ def send_code_request_view(request):
     if Login.objects.filter(client_session=client_session).have_to_send_code().exists():
         return JsonResponse({'error': 'Client session is already waiting for send code.'}, status=400)
 
-    login = Login.objects.create(client_session=client_session, phone_number=phone_number, have_to_send_code=True)
+    login = Login.objects.create(
+        client_session=client_session, phone_number=phone_number, have_to_send_code=True
+    )
     return JsonResponse({'login_id': login.id}, status=200)
 
 
+@csrf_exempt
 def login_user_view(request):
     data = _get_data(request)
     client_session_name = data.get('client_session_name', None)
@@ -69,6 +74,7 @@ def login_user_view(request):
     return JsonResponse({}, status=200)
 
 
+@csrf_exempt
 def login_bot_view(request):
     data = _get_data(request)
     client_session_name = data.get('client_session_name', None)
@@ -80,7 +86,7 @@ def login_bot_view(request):
     if not bot_token or not client_session_name:
         return JsonResponse({'error': 'Missing bot token or client session name or code'}, status=400)
 
-    client_session = ClientSession.objects.get_or_create(name=client_session_name)
+    client_session, _ = ClientSession.objects.get_or_create(name=client_session_name)
 
     if client_session.login_status != LoginStatus.LOGIN_REQUIRED:
         return JsonResponse({'error': 'Client session is not in login required status'}, status=400)
